/***************************************************************************
                          metainfo.cpp  -  description
                             -------------------
    begin                : Mon Dec 9 2002
    copyright            : (C) 2002-2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "metainfo.h"

#include <kfileitem.h>
#include <kio/global.h>
#include <ksqueezedtextlabel.h>
#include <klocale.h>

MetaInfo::MetaInfo(QWidget *parent, const char *name ) : MetaInfoBase(parent,name) {
}

MetaInfo::~MetaInfo(){
}

// Display info about a file at the given path
void MetaInfo::slotNewFile(const QString &path){

	// Check if path points to readable file
	KFileItem file(KFileItem::Unknown, KFileItem::Unknown, path, false);
	if(file.isReadable() && file.isFile()) {

		// Display the mime type if we know what it's recognised
		if(file.isMimeTypeKnown())
			typeLabel->setText(file.mimeComment());
		else
			typeLabel->setText(i18n("Unknown"));

		// Display size
		sizeLabel->setText(KIO::convertSize(file.size()));

		// Get meta info
		const KFileMetaInfo info = file.metaInfo();
		if(info.isValid()) {
			const KFileMetaInfoItem sizeInfo = info.item(KFileMimeTypeInfo::Size);

			// Display demensions
			dimensionsLabel->setText(sizeInfo.string());
		} else
			dimensionsLabel->setText("---");

	} else {

		// Reset display
		typeLabel->setText(QString::null);
		sizeLabel->setText(QString::null);
		dimensionsLabel->setText(QString::null);
	}
}
