/***************************************************************************
                           qobex.h  -  description
                             -------------------
    begin                : Tue Dec 10 2002
    copyright            : (C) 2002 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QOBEX_H
#define QOBEX_H

#include <qobject.h>
#include <qsocketnotifier.h>
#include <qcstring.h>

class QObexObject;

extern "C" {
	#include <openobex/obex.h>
}

extern "C" void QObex_handleEvent(obex_t *, obex_object_t *, int, int, int, int);

class QObex : public QObject
{
Q_OBJECT

public:
	QObex();
	virtual ~QObex();
	void request(QObexObject&);
	virtual bool transportConnect() = 0;
	void transportDisconnect();

	enum Command { Connect = OBEX_CMD_CONNECT,
                   Disconnect = OBEX_CMD_DISCONNECT,
                   Put = OBEX_CMD_PUT,
				   Get = OBEX_CMD_GET,
				   SetPath = OBEX_CMD_SETPATH,
				   Abort = OBEX_CMD_ABORT };

   	enum Response {	Continue = OBEX_RSP_CONTINUE,
                    SwitchPro = OBEX_RSP_SWITCH_PRO,
                    Success = OBEX_RSP_SUCCESS,
                    Created = OBEX_RSP_CREATED,
                    Accepted = OBEX_RSP_ACCEPTED,
                    NoContent = OBEX_RSP_NO_CONTENT,
                    BadRequest = OBEX_RSP_BAD_REQUEST,
                    Unauthorized = OBEX_RSP_UNAUTHORIZED,
                    PaymentRequired = OBEX_RSP_PAYMENT_REQUIRED,
                    Forbidden = OBEX_RSP_FORBIDDEN,
                    NotFound = OBEX_RSP_NOT_FOUND,
                    MethodNotAllowed = OBEX_RSP_METHOD_NOT_ALLOWED,
                    Conflict = OBEX_RSP_CONFLICT,
                    InternalServerError = OBEX_RSP_INTERNAL_SERVER_ERROR,
                    NotImplemented = OBEX_RSP_NOT_IMPLEMENTED,
                    DatabaseFull = OBEX_RSP_DATABASE_FULL,
                    DatabaseLocked = OBEX_RSP_DATABASE_LOCKED };

    static QString responseToQString(Response);
    static QByteArray* qStringToUnicode(const QString&);

signals:
	void progressMade();
	void requestAborted();
	void requestDone(QObexObject&, QObex::Command, QObex::Response);
	void linkError();
	void streamEmpty(QObexObject&);
    void idle();

protected:
	obex_t* obex;
	QSocketNotifier* notifier;
	virtual void createNotifier();
	void handleEvent(obex_object_t*, int, int, int, int);

protected slots:
    void slotHandleInput(int);
    void slotIdle();

friend class QObexObject;
friend void QObex_handleEvent(obex_t *, obex_object_t *, int, int, int, int);
};

#endif
