/***************************************************************************
                          qobexclient.cpp  -  description
                             -------------------
    begin                : Fri Dec 20 2002
    copyright            : (C) 2002-2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qobexclient.h"

#include "qobexobject.h"
#include "qobexheader.h"

#include <qfile.h>
#include <qfileinfo.h>

#include <klocale.h>


QObexClient::QObexClient(QObex& o) : obex(o) {
    connect(&obex, SIGNAL(requestDone(QObexObject&, QObex::Command, QObex::Response)), this, SLOT(slotRequestDone(QObexObject&, QObex::Command, QObex::Response)));
    connect(&obex, SIGNAL(idle()), this, SLOT(slotIdle()));
}

QObexClient::~QObexClient() {
    
}


void QObexClient::slotRequestDone(QObexObject& object, QObex::Command cmd, QObex::Response rsp) {

    if(cmd == QObex::Connect) {
        if(rsp == QObex::Success)
            state = Connected;
        else {
            QString msg(i18n("Error connecting to phone\nResponse message: "));
            msg += QObex::responseToQString(rsp);
            emit error(msg);
            state = Error;
        }
    } else if(cmd == QObex::Disconnect) {
        state = Disconnected;
        obex.transportDisconnect();
    } else if(cmd == QObex::Put) {
        if(rsp == QObex::Success) {
            state = Finished;
        } else {
            QString msg(i18n("Error sending file to phone\nResponse message: "));
            msg += QObex::responseToQString(rsp);
            emit error(msg);
            state = Error;
        }
	} else if(cmd == QObex::Get) {
		if(rsp == QObex::Success) {
			state = Finished;
		} else {
			QString msg(i18n("Error getting data from phone\nResponse message: "));
			msg += QObex::responseToQString(rsp);
			emit error(msg);
			state = Error;
		}
	}

	if(state == Finished)
		finishOp(object);
}


void QObexClient::slotIdle() {
    if(state == Connected)
        startOp();
    else if(state == Finished || state == Error)
        disconnectClient();
    else if(state == Disconnected) {
        emit info(baseInfoMsg + i18n("Done"));
		emit done();
    }
}


void QObexClient::start() {

    // Set state
    state = Connecting;

    // Let everyone know what we're up to
    emit info(baseInfoMsg + i18n("Connecting..."));

    // Attempt to connect transport
    if(!obex.transportConnect()) {
        emit error(i18n("Error connecting transport"));
        emit done();
        return;
    }

    // Create connect object
	QObexObject object(obex, QObex::Connect);

	// Create who header and add to header
	const char* who = "Linux";
	QObexHeader whoHeader(QObexHeader::Who, (uint8_t*) who, 6);
	object.addHeader(whoHeader, QObexObject::FitOnePacket);

    // Send request
	obex.request(object);
}


void QObexClient::disconnectClient() {

    // Set state
    state = Disconnecting;

    // Let everyone known what we're up to
    emit info(baseInfoMsg + i18n("Disconnecting..."));

	// Create disconnect object
	QObexObject object(obex, QObex::Disconnect);

	// Send request
	obex.request(object);
}

