/***************************************************************************
                          qobexclientget.cpp  -  description
                             -------------------
    begin                : Sun Jan 26 2003
    copyright            : (C) 2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qobexclientget.h"
#include "qobexobject.h"
#include "qobexheader.h"

#include <klocale.h>

QObexClientGet::QObexClientGet(QObex& o, const QString& src) : QObexClient(o), source(src) {

	// Monitor non-quantative progress
	connect(&obex, SIGNAL(progressMade()), this, SLOT(slotProgress()));

	// Info message base
    baseInfoMsg = i18n("Getting ") + src + i18n(" from phone\n\n");
}

QObexClientGet::~QObexClientGet() {

}

void QObexClientGet::slotProgress() {
	emit progress();
}

void QObexClientGet::startOp() {

    // Set state
    state = Running;

    // Let everyone know what we're up to
    emit info(baseInfoMsg + i18n("Requesting data..."));

    // Create object
	QObexObject object(obex, QObex::Get);

    // Create name header and add to object
	QByteArray* unicode = QObex::qStringToUnicode(source);
	QObexHeader nameHeader(QObexHeader::Name, (uint8_t*) unicode->data(), unicode->size());
	object.addHeader(nameHeader, QObexObject::None);
    delete unicode;

    // Send object
	obex.request(object);
}

void QObexClientGet::finishOp(QObexObject& object) {

    // Find body header
    QObexHeader *header;
    do {
        header = object.getNextHeader();
    } while(header->type() != QObexHeader::Body);

    // Get data
    const uint8_t* bs;
    uint32_t size;
    header->data(bs, size);

    // Create and fill buffer
    QByteArray buffer;
    buffer.duplicate((char*) bs, size);

    // Emit signal
    emit data(buffer);
}

