/***************************************************************************
                          qobexclientput.cpp  -  description
                             -------------------
    begin                : Sun Jan 26 2003
    copyright            : (C) 2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qobexclientput.h"
#include "qobexobject.h"
#include "qobexheader.h"

#include <qfile.h>
#include <qfileinfo.h>

#include <klocale.h>

QObexClientPut::QObexClientPut(QObex& o, const QString& src, const QString& dst) : QObexClient(o) {
    connect(&obex, SIGNAL(streamEmpty(QObexObject&)), this, SLOT(slotStreamEmpty(QObexObject&)));

	// Put file
	put(src, dst);
}

QObexClientPut::QObexClientPut(QObex& o, const QString& src) : QObexClient(o) {
    connect(&obex, SIGNAL(streamEmpty(QObexObject&)), this, SLOT(slotStreamEmpty(QObexObject&)));

    // Find file name
    QFileInfo info(src);
    QString dst = info.fileName();

    // Push is just a put with filename as destination
    put(src, dst);
}

QObexClientPut::~QObexClientPut() {
    
}


void QObexClientPut::put(const QString& src, const QString& dst) {

    // Open file
	QFile file(src);
	file.open(IO_ReadOnly);

    // Read data
    buffer = file.readAll();

	// Close file
	file.close();

	// Store some things
    current = 0;
    target = dst;
    baseInfoMsg = i18n("Sending ") + src + i18n(" to phone\n\n");
}    


void QObexClientPut::slotStreamEmpty(QObexObject& object) {

    // Emit signal for current position in file
    emit progress(current);

    /* Test for current is workaround for getting stream empty signal
     * before file has been accepted on the phone */
    if(current != 0) {
      emit info(baseInfoMsg + i18n("Streaming data..."));
    }

    // Check to see if everything has already been sent
    if(current == buffer.size()) {
        // Add end stream header to object
        QObexHeader endHeader(QObexHeader::Body, (uint8_t*) buffer.data() + current, 0);
        object.addHeader(endHeader, QObexObject::StreamEnd);
    } else {
        // Create body header to and add to object
        int remain = buffer.size() - current;
        if(remain < streamChunk) {
            QObexHeader dataHeader(QObexHeader::Body, (uint8_t*) (buffer.data() + current), remain);
            object.addHeader(dataHeader, QObexObject::StreamData);
            current += remain;
        } else {
            QObexHeader dataHeader(QObexHeader::Body, (uint8_t*) (buffer.data() + current), streamChunk);
            object.addHeader(dataHeader, QObexObject::StreamData);
            current += streamChunk;
        }
    }
}


void QObexClientPut::startOp() {

    // Set state
    state = Running;

	// Inform others of size of file
	emit totalSize(buffer.size());

    // Let everyone know what we're up to
    emit info(baseInfoMsg + i18n("Requesting stream start..."));

    // Create object
	QObexObject object(obex, QObex::Put);

	// Create name header and add to object
	QByteArray* unicode = QObex::qStringToUnicode(target);
	QObexHeader nameHeader(QObexHeader::Name, (uint8_t*) unicode->data(), unicode->size());
	object.addHeader(nameHeader, QObexObject::None);
    delete unicode;

	// Create length header and add to object
	QObexHeader lengthHeader(QObexHeader::Length, (uint32_t) buffer.size(), 4);
	object.addHeader(lengthHeader, QObexObject::None);

	// Signify that this is the start of a stream
	QObexHeader streamHeader(QObexHeader::Body, (uint8_t*) NULL, 0);
	object.addHeader(streamHeader, QObexObject::StreamStart);

    // Send object
	obex.request(object);
}


void QObexClientPut::finishOp(QObexObject& /* object */) {
}

