/***************************************************************************
                          sendfile.cpp  -  description
                             -------------------
    begin                : Sun Nov 10 2002
    copyright            : (C) 2002-2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "sendfile.h"
#include "sender.h"
#include "metainfo.h"

#include <qgroupbox.h>
#include <qlayout.h>

#include <kmessagebox.h>
#include <klocale.h>

SendFile::SendFile(QObex *obex, QWidget *parent, const char *name)
	: SendFileBase(parent,name), obex(obex) {

    // Set up display of file info
	MetaInfo *fileInfo = new MetaInfo(fileInfoBox);
	fileInfoBox->setColumnLayout(0, Qt::Vertical);
	fileInfoBox->layout()->setAlignment(Qt::AlignTop);
	fileInfoBox->layout()->add(fileInfo);

	// Connect signals/slots for meta info display
	connect(urlRequester, SIGNAL(urlSelected(const QString &)),
			fileInfo, SLOT(slotNewFile(const QString &)));

	connect(urlRequester, SIGNAL(textChanged(const QString &)),
			fileInfo, SLOT(slotNewFile(const QString &)));

	// Connect signal/slot for click on send button
	connect(sendButton, SIGNAL(clicked()), this, SLOT(slotSend()));
}

SendFile::~SendFile() {
}

void SendFile::setObex(QObex *obex) {
	this->obex = obex;
}

void SendFile::slotSend() {

	// Read current selected path (may be invalid)
    QString path = urlRequester->url();

	// Check if a path has been entered
	if(path.isEmpty()) {
		KMessageBox::sorry(this, i18n("No file selected"));
		return;
	}

	// Check if path points to readable file
	QFileInfo info(path);
	if(!info.isReadable() || !info.isFile()) {
 		KMessageBox::sorry(this, path + i18n("\nFile does not exist or is not readable."));
    }

	// Create sender
	KURL url(path);
	sender = new Sender(obex, url, this, 0, i18n("Sending file to phone"),
						QString::null, true);
	connect(sender, SIGNAL(closeClicked()), this, SLOT(slotDeleteSender()));
}

void SendFile::slotDeleteSender() {
	sender->delayedDestruct();
}

