/***************************************************************************
                     serialcablesettings.cpp  -  description
                             -------------------
    begin                : Fri Dec 13 2002
    copyright            : (C) 2002 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "serialcablesettings.h"

#include <qcombobox.h>
#include <qcheckbox.h>

#include <kapp.h>
#include <kconfig.h>

const char* const SerialCableSettings::configGroup = "Serial Settings";
const char* const SerialCableSettings::configDevice = "Device";
const char* const SerialCableSettings::configDeviceDefault = "/dev/ttyS0";
const char* const SerialCableSettings::configBaudRate = "Baud Rate";

SerialCableSettings::SerialCableSettings(QWidget *parent, const char *name ) : SerialCableSettingsBase(parent,name) {

    // Load and display current settings
    kapp->config()->setGroup(configGroup);
	device->setCurrentText(kapp->config()->readEntry(configDevice, configDeviceDefault));
    QString num;
	baudRate->setCurrentText(num.setNum(kapp->config()->readNumEntry(configBaudRate, configBaudDefault)));

    // Connect signals/slots
    connect(device, SIGNAL(textChanged(const QString&)), this, SLOT(slotDevice(const QString&)));
	connect(baudRate, SIGNAL(activated(const QString&)), this, SLOT(slotBaudRate(const QString&)));
}

SerialCableSettings::~SerialCableSettings(){
}

void SerialCableSettings::slotDevice(const QString& dev) {
	kapp->config()->setGroup(configGroup);
	kapp->config()->writeEntry(configDevice, dev);

	emit settingsChanged();
}

void SerialCableSettings::slotBaudRate(const QString& rate) {
    kapp->config()->setGroup(configGroup);
	kapp->config()->writeEntry(configBaudRate, rate.toInt());

	emit settingsChanged();
}
