/***************************************************************************
                          settings.cpp  -  description
                             -------------------
    begin                : Mon Dec 9 2002
    copyright            : (C) 2002 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "settings.h"

#include "bluetoothsettings.h"
#include "infraredsettings.h"
#include "serialcablesettings.h"

#include <qgroupbox.h>
#include <qlayout.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>

#include <kapp.h>
#include <kconfig.h>

const char* const Settings::configGroup = "General";
const char* const Settings::configTransport = "Transport";
const char* const Settings::configBluetooth = "Bluetooth";
const char* const Settings::configInfrared = "Infrared";
const char* const Settings::configSerialCable = "Serial Cable";

Settings::Settings(QWidget *parent, const char *name) : SettingsBase(parent,name) {
	
	// Create stack to hold transport settings
	stack = new QWidgetStack(transSetBox);
    transSetBox->setColumnLayout(0, Qt::Vertical);
	transSetBox->layout()->setAlignment(Qt::AlignTop);
	transSetBox->layout()->add(stack);

	// Create transport settings widgets
	bluetoothSettings = new BluetoothSettings(stack);
	infraredSettings = new InfraredSettings(stack);
	serialCableSettings = new SerialCableSettings(stack);

	// Add to stack
	stack->addWidget(bluetoothSettings, -1);
	stack->addWidget(infraredSettings, -1);
	stack->addWidget(serialCableSettings, -1);

	// Read transport from config file
	kapp->config()->setGroup(configGroup);
	QString tmp = kapp->config()->readEntry(configTransport, configSerialCable);
#ifdef HAVE_BLUETOOTH
	if(tmp.compare(configBluetooth) == 0) {
		bluetooth->setChecked(true);
		stack->raiseWidget(bluetoothSettings);
	} else
#endif
	if(tmp.compare(configInfrared) == 0) {
		infrared->setChecked(true);
		stack->raiseWidget(infraredSettings);
	} else {
		serialCable->setChecked(true);
		stack->raiseWidget(serialCableSettings);
	}

    // Monitor which transport is selected
    connect(transport, SIGNAL(clicked(int)), this, SLOT(slotTransport(int)));

    // Monitor change of settings
    connect(bluetoothSettings, SIGNAL(settingsChanged()), this, SLOT(slotSettingsChanged()));
    connect(infraredSettings, SIGNAL(settingsChanged()), this, SLOT(slotSettingsChanged()));
    connect(serialCableSettings, SIGNAL(settingsChanged()), this, SLOT(slotSettingsChanged()));

#ifndef HAVE_BLUETOOTH
	bluetooth->setEnabled(false);
#endif
}

Settings::~Settings() {
}

void Settings::slotTransport(int id) {

	kapp->config()->setGroup(configGroup);

	if(id == transport->id(bluetooth)) {
		kapp->config()->writeEntry(configTransport, configBluetooth);
		stack->raiseWidget(bluetoothSettings);
	} else if(id == transport->id(infrared)) {
		kapp->config()->writeEntry(configTransport, configInfrared);
		stack->raiseWidget(infraredSettings);
    } else {
		kapp->config()->writeEntry(configTransport, configSerialCable);
		stack->raiseWidget(serialCableSettings);
	}

	emit settingsChanged();
}

void Settings::slotSettingsChanged() {
	emit settingsChanged();
}

